# Application Portfolio Management Dashboard
### On this page
  * [Dashboard Structure](https://help.sap.com/docs/leanix/ea/application-portfolio-management-dashboard#dashboard-structure)
  * [General Features of the Dashboard](https://help.sap.com/docs/leanix/ea/application-portfolio-management-dashboard#general-features-of-the-dashboard)
  * [Live Applications by Business Capability](https://help.sap.com/docs/leanix/ea/application-portfolio-management-dashboard#live-applications-by-business-capability)
  * [Application Run Cost Broken Down by Business Capability](https://help.sap.com/docs/leanix/ea/application-portfolio-management-dashboard#application-run-cost-broken-down-by-business-capability)
  * [Portfolio Complexity](https://help.sap.com/docs/leanix/ea/application-portfolio-management-dashboard#portfolio-complexity)
  * [Data Quality KPI](https://help.sap.com/docs/leanix/ea/application-portfolio-management-dashboard#data-quality-kpi)


Use the Application Portfolio Management Dashboard to analyze your application portfolio.
**Note**
The Application Portfolio Management dashboard is available in all SAP LeanIX products.
